@@ -7,13 +7,22 @@ use std::{
 };
 
 use anyhow::{Context, Result};
-use clap::Args;
+use clap::{ArgEnum, Args};
 use sha1::{Digest, Sha1};
 use swc_common::SourceMap;
 
 #[derive(Debug, Args)]
 pub struct ReduceCommand {
     pub path: PathBuf,
+
+    #[clap(long, arg_enum)]
+    pub mode: ReduceMode,
+}
+
+#[derive(Debug, Clone, Copy, ArgEnum)]
+pub enum ReduceMode {
+    Size,
+    Semantics,
 }
 
 impl ReduceCommand {
@@ -21,13 +30,22 @@ impl ReduceCommand {
         fs::copy(&self.path, "input.js").context("failed to copy")?;
 
         let mut c = Command::new("creduce");
-        c.env("CREDUCE_COMPARE", "1");
+
+        c.env(
+            "CREDUCE_COMPARE",
+            match self.mode {
+                ReduceMode::Size => "SIZE",
+                ReduceMode::Semantics => "SEMANTICS",
+            },
+        );
         let exe = current_exe()?;
         c.arg(&exe);
         c.arg("input.js");
-        c.status().context("failed to run creduce")?;
+        let status = c.status().context("failed to run creduce")?;
 
-        move_to_data_dir("input.js".as_ref())?;
+        if status.success() {
+            move_to_data_dir("input.js".as_ref())?;
+        }
 
         Ok(())
     }
@@ -47,9 +65,9 @@ fn move_to_data_dir(input_path: &Path) -> Result<PathBuf> {
     let result = hasher.finalize();
     let hash_str = format!("{:x}", result);
 
-    create_dir_all(".data").context("failed to create `.data`")?;
+    create_dir_all("data").context("failed to create `.data`")?;
 
-    let to = PathBuf::from(format!(".data/{}.js", hash_str));
+    let to = PathBuf::from(format!("data/{}.js", hash_str));
     fs::copy(input_path, &to).context("failed to copy")?;
 
     Ok(to)
